---
title: <span class="badge object-type-enum"></span> LokiQueryType
---
# <span class="badge object-type-enum"></span> LokiQueryType

## Definition

```python
class LokiQueryType(enum.StrEnum):
    RANGE = "range"
    INSTANT = "instant"
    STREAM = "stream"
```
